pub struct ValidationAlert {
pub style: AlertStyle,
pub title: String,
pub message: String,
}Fields
style: AlertStyletitle: Stringmessage: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ValidationAlert
impl<'de> Deserialize<'de> for ValidationAlert
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidationAlert
impl JsonSchema for ValidationAlert
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ValidationAlert
impl RefUnwindSafe for ValidationAlert
impl Send for ValidationAlert
impl Sync for ValidationAlert
impl Unpin for ValidationAlert
impl UnsafeUnpin for ValidationAlert
impl UnwindSafe for ValidationAlert