pub struct ValidationMessage {
pub title: String,
pub body: String,
}Fields
title: Stringbody: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ValidationMessage
impl<'de> Deserialize<'de> for ValidationMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidationMessage
impl JsonSchema for ValidationMessage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ValidationMessage
impl RefUnwindSafe for ValidationMessage
impl Send for ValidationMessage
impl Sync for ValidationMessage
impl Unpin for ValidationMessage
impl UnsafeUnpin for ValidationMessage
impl UnwindSafe for ValidationMessage