pub struct AddBoxWhiskerChartInput {
pub workbook_id: String,
pub sheet_name: String,
pub title: Option<String>,
pub series_name: Option<String>,
pub points: Vec<FunnelPoint>,
pub show_outliers: Option<bool>,
pub show_mean: Option<bool>,
pub show_inner_points: Option<bool>,
pub width: u32,
pub height: u32,
pub cell: Option<String>,
}Expand description
Input for adding a box & whisker chart (Excel 2016+ ChartEx)
Fields
workbook_id: Stringsheet_name: Stringtitle: Option<String>series_name: Option<String>points: Vec<FunnelPoint>show_outliers: Option<bool>Show outlier points
show_mean: Option<bool>Show mean markers
show_inner_points: Option<bool>Show inner data points
width: u32height: u32cell: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddBoxWhiskerChartInput
impl<'de> Deserialize<'de> for AddBoxWhiskerChartInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddBoxWhiskerChartInput
impl JsonSchema for AddBoxWhiskerChartInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddBoxWhiskerChartInput
impl RefUnwindSafe for AddBoxWhiskerChartInput
impl Send for AddBoxWhiskerChartInput
impl Sync for AddBoxWhiskerChartInput
impl Unpin for AddBoxWhiskerChartInput
impl UnsafeUnpin for AddBoxWhiskerChartInput
impl UnwindSafe for AddBoxWhiskerChartInput