pub struct AddChartSheetInput {
pub workbook_id: String,
pub sheet_name: String,
pub chart_type: ChartType,
pub series: Vec<ChartSeriesInput>,
pub data_range: Option<String>,
pub title: Option<String>,
pub x_axis_label: Option<String>,
pub y_axis_label: Option<String>,
pub legend_position: Option<LegendPosition>,
}Expand description
Input for adding a chart sheet (dedicated chart-only sheet)
Fields
workbook_id: Stringsheet_name: Stringchart_type: ChartTypeseries: Vec<ChartSeriesInput>data_range: Option<String>title: Option<String>x_axis_label: Option<String>y_axis_label: Option<String>legend_position: Option<LegendPosition>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddChartSheetInput
impl<'de> Deserialize<'de> for AddChartSheetInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddChartSheetInput
impl JsonSchema for AddChartSheetInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddChartSheetInput
impl RefUnwindSafe for AddChartSheetInput
impl Send for AddChartSheetInput
impl Sync for AddChartSheetInput
impl Unpin for AddChartSheetInput
impl UnsafeUnpin for AddChartSheetInput
impl UnwindSafe for AddChartSheetInput