pub struct AddConnectionInput {
pub workbook_id: String,
pub connection_string: String,
pub command: String,
}Expand description
Input for adding an external data connection
Fields
workbook_id: Stringconnection_string: Stringcommand: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for AddConnectionInput
impl<'de> Deserialize<'de> for AddConnectionInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddConnectionInput
impl JsonSchema for AddConnectionInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddConnectionInput
impl RefUnwindSafe for AddConnectionInput
impl Send for AddConnectionInput
impl Sync for AddConnectionInput
impl Unpin for AddConnectionInput
impl UnsafeUnpin for AddConnectionInput
impl UnwindSafe for AddConnectionInput