pub struct AddHistogramChartInput {
pub workbook_id: String,
pub sheet_name: String,
pub title: Option<String>,
pub series_name: Option<String>,
pub points: Vec<FunnelPoint>,
pub bin_count: Option<u32>,
pub bin_width: Option<f64>,
pub pareto: Option<bool>,
pub width: u32,
pub height: u32,
pub cell: Option<String>,
}Expand description
Input for adding a histogram chart (Excel 2016+ ChartEx)
Fields
workbook_id: Stringsheet_name: Stringtitle: Option<String>series_name: Option<String>points: Vec<FunnelPoint>bin_count: Option<u32>bin_width: Option<f64>pareto: Option<bool>Show Pareto line overlay
width: u32height: u32cell: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddHistogramChartInput
impl<'de> Deserialize<'de> for AddHistogramChartInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddHistogramChartInput
impl JsonSchema for AddHistogramChartInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddHistogramChartInput
impl RefUnwindSafe for AddHistogramChartInput
impl Send for AddHistogramChartInput
impl Sync for AddHistogramChartInput
impl Unpin for AddHistogramChartInput
impl UnsafeUnpin for AddHistogramChartInput
impl UnwindSafe for AddHistogramChartInput