pub struct AddLinkInput {
pub workbook_id: String,
pub sheet_name: String,
pub cell: String,
pub link_type: String,
pub target: String,
pub display_text: Option<String>,
pub tooltip: Option<String>,
}Fields
workbook_id: Stringsheet_name: Stringcell: Stringlink_type: String“url” or “internal”
target: StringURL for external, or “Sheet2!A1” for internal
display_text: Option<String>tooltip: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddLinkInput
impl<'de> Deserialize<'de> for AddLinkInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddLinkInput
impl JsonSchema for AddLinkInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddLinkInput
impl RefUnwindSafe for AddLinkInput
impl Send for AddLinkInput
impl Sync for AddLinkInput
impl Unpin for AddLinkInput
impl UnsafeUnpin for AddLinkInput
impl UnwindSafe for AddLinkInput