pub struct AddMapChartInput {
pub workbook_id: String,
pub sheet_name: String,
pub title: Option<String>,
pub series_name: Option<String>,
pub points: Vec<FunnelPoint>,
pub map_level: Option<String>,
pub width: u32,
pub height: u32,
pub cell: Option<String>,
}Expand description
Input for adding a map chart (Excel 2016+ ChartEx)
Fields
workbook_id: Stringsheet_name: Stringtitle: Option<String>series_name: Option<String>points: Vec<FunnelPoint>map_level: Option<String>Map level: “world”, “continent”, “country”, “state”
width: u32height: u32cell: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddMapChartInput
impl<'de> Deserialize<'de> for AddMapChartInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddMapChartInput
impl JsonSchema for AddMapChartInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddMapChartInput
impl RefUnwindSafe for AddMapChartInput
impl Send for AddMapChartInput
impl Sync for AddMapChartInput
impl Unpin for AddMapChartInput
impl UnsafeUnpin for AddMapChartInput
impl UnwindSafe for AddMapChartInput