pub struct AddSlicerInput {
pub workbook_id: String,
pub sheet_name: String,
pub pivot_table_name: String,
pub field_name: String,
pub cell: Option<String>,
pub width: Option<u32>,
pub height: Option<u32>,
}Expand description
Input for adding a slicer to a pivot table
Fields
workbook_id: Stringsheet_name: Stringpivot_table_name: StringName of the pivot table to connect to
field_name: StringField name to filter on
cell: Option<String>Anchor cell for the slicer
width: Option<u32>height: Option<u32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddSlicerInput
impl<'de> Deserialize<'de> for AddSlicerInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddSlicerInput
impl JsonSchema for AddSlicerInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddSlicerInput
impl RefUnwindSafe for AddSlicerInput
impl Send for AddSlicerInput
impl Sync for AddSlicerInput
impl Unpin for AddSlicerInput
impl UnsafeUnpin for AddSlicerInput
impl UnwindSafe for AddSlicerInput