pub struct AddSunburstChartInput {
pub workbook_id: String,
pub sheet_name: String,
pub title: Option<String>,
pub series_name: Option<String>,
pub points: Vec<TreemapPoint>,
pub width: u32,
pub height: u32,
pub cell: Option<String>,
}Expand description
Input for adding a sunburst chart (Excel 2016+ ChartEx)
Fields
workbook_id: Stringsheet_name: Stringtitle: Option<String>series_name: Option<String>points: Vec<TreemapPoint>width: u32height: u32cell: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddSunburstChartInput
impl<'de> Deserialize<'de> for AddSunburstChartInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddSunburstChartInput
impl JsonSchema for AddSunburstChartInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddSunburstChartInput
impl RefUnwindSafe for AddSunburstChartInput
impl Send for AddSunburstChartInput
impl Sync for AddSunburstChartInput
impl Unpin for AddSunburstChartInput
impl UnsafeUnpin for AddSunburstChartInput
impl UnwindSafe for AddSunburstChartInput