pub struct AltTextInput {
pub title: String,
pub description: String,
}Fields
title: Stringdescription: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for AltTextInput
impl<'de> Deserialize<'de> for AltTextInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AltTextInput
impl JsonSchema for AltTextInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AltTextInput
impl RefUnwindSafe for AltTextInput
impl Send for AltTextInput
impl Sync for AltTextInput
impl Unpin for AltTextInput
impl UnsafeUnpin for AltTextInput
impl UnwindSafe for AltTextInput