pub struct AutofitColumnsInput {
pub workbook_id: String,
pub sheet_name: String,
}Expand description
Input for autofitting column widths
Fields
workbook_id: Stringsheet_name: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for AutofitColumnsInput
impl<'de> Deserialize<'de> for AutofitColumnsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutofitColumnsInput
impl JsonSchema for AutofitColumnsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AutofitColumnsInput
impl RefUnwindSafe for AutofitColumnsInput
impl Send for AutofitColumnsInput
impl Sync for AutofitColumnsInput
impl Unpin for AutofitColumnsInput
impl UnsafeUnpin for AutofitColumnsInput
impl UnwindSafe for AutofitColumnsInput