pub struct ClearCellInput {
pub workbook_id: String,
pub sheet_name: String,
pub cell: String,
}Fields
workbook_id: Stringsheet_name: Stringcell: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ClearCellInput
impl<'de> Deserialize<'de> for ClearCellInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClearCellInput
impl JsonSchema for ClearCellInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ClearCellInput
impl RefUnwindSafe for ClearCellInput
impl Send for ClearCellInput
impl Sync for ClearCellInput
impl Unpin for ClearCellInput
impl UnsafeUnpin for ClearCellInput
impl UnwindSafe for ClearCellInput