pub struct FitToPages {
pub width: u16,
pub height: u16,
}Expand description
Fit-to-page settings
Fields
width: u16height: u16Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FitToPages
impl<'de> Deserialize<'de> for FitToPages
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FitToPages
impl JsonSchema for FitToPages
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FitToPages
impl RefUnwindSafe for FitToPages
impl Send for FitToPages
impl Sync for FitToPages
impl Unpin for FitToPages
impl UnsafeUnpin for FitToPages
impl UnwindSafe for FitToPages