pub struct FunnelPoint {
pub category: String,
pub value: f64,
}Expand description
A single data point for a funnel chart
Fields
category: Stringvalue: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FunnelPoint
impl<'de> Deserialize<'de> for FunnelPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunnelPoint
impl JsonSchema for FunnelPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunnelPoint
impl RefUnwindSafe for FunnelPoint
impl Send for FunnelPoint
impl Sync for FunnelPoint
impl Unpin for FunnelPoint
impl UnsafeUnpin for FunnelPoint
impl UnwindSafe for FunnelPoint