pub struct GroupColumnsInput {
pub workbook_id: String,
pub sheet_name: String,
pub start: String,
pub end: String,
pub level: u8,
}Expand description
Input for grouping columns
Fields
workbook_id: Stringsheet_name: Stringstart: StringFirst column letter
end: StringLast column letter
level: u8Trait Implementations
Sourceimpl<'de> Deserialize<'de> for GroupColumnsInput
impl<'de> Deserialize<'de> for GroupColumnsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GroupColumnsInput
impl JsonSchema for GroupColumnsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GroupColumnsInput
impl RefUnwindSafe for GroupColumnsInput
impl Send for GroupColumnsInput
impl Sync for GroupColumnsInput
impl Unpin for GroupColumnsInput
impl UnsafeUnpin for GroupColumnsInput
impl UnwindSafe for GroupColumnsInput