pub struct GroupInput {
pub workbook_id: String,
pub sheet_name: String,
pub target: String,
pub start: String,
pub end: String,
pub level: u8,
}Fields
workbook_id: Stringsheet_name: Stringtarget: String“rows” or “columns”
start: StringFor rows: 1-based row numbers. For columns: column letters.
end: Stringlevel: u8Trait Implementations
Sourceimpl<'de> Deserialize<'de> for GroupInput
impl<'de> Deserialize<'de> for GroupInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GroupInput
impl JsonSchema for GroupInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GroupInput
impl RefUnwindSafe for GroupInput
impl Send for GroupInput
impl Sync for GroupInput
impl Unpin for GroupInput
impl UnsafeUnpin for GroupInput
impl UnwindSafe for GroupInput