pub struct InsertDeleteColumnsInput {
pub workbook_id: String,
pub sheet_name: String,
pub at_column: String,
pub count: u16,
}Expand description
Input for inserting/deleting columns
Fields
workbook_id: Stringsheet_name: Stringat_column: StringColumn letter where insertion/deletion starts (e.g. “C”)
count: u16Trait Implementations
Sourceimpl<'de> Deserialize<'de> for InsertDeleteColumnsInput
impl<'de> Deserialize<'de> for InsertDeleteColumnsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InsertDeleteColumnsInput
impl JsonSchema for InsertDeleteColumnsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InsertDeleteColumnsInput
impl RefUnwindSafe for InsertDeleteColumnsInput
impl Send for InsertDeleteColumnsInput
impl Sync for InsertDeleteColumnsInput
impl Unpin for InsertDeleteColumnsInput
impl UnsafeUnpin for InsertDeleteColumnsInput
impl UnwindSafe for InsertDeleteColumnsInput