pub struct ManageCellInput {
pub workbook_id: String,
pub sheet_name: String,
pub cell: String,
pub action: String,
pub background_color: Option<String>,
pub number_format: Option<String>,
}Fields
workbook_id: Stringsheet_name: Stringcell: Stringaction: String“blank” or “clear”
background_color: Option<String>number_format: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ManageCellInput
impl<'de> Deserialize<'de> for ManageCellInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManageCellInput
impl JsonSchema for ManageCellInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ManageCellInput
impl RefUnwindSafe for ManageCellInput
impl Send for ManageCellInput
impl Sync for ManageCellInput
impl Unpin for ManageCellInput
impl UnsafeUnpin for ManageCellInput
impl UnwindSafe for ManageCellInput