pub struct ManageCommentsInput {
pub workbook_id: String,
pub sheet_name: String,
pub action: String,
pub cell: Option<String>,
pub text: Option<String>,
pub author: Option<String>,
}Fields
workbook_id: Stringsheet_name: Stringaction: String“add” or “read”
cell: Option<String>text: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ManageCommentsInput
impl<'de> Deserialize<'de> for ManageCommentsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManageCommentsInput
impl JsonSchema for ManageCommentsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ManageCommentsInput
impl RefUnwindSafe for ManageCommentsInput
impl Send for ManageCommentsInput
impl Sync for ManageCommentsInput
impl Unpin for ManageCommentsInput
impl UnsafeUnpin for ManageCommentsInput
impl UnwindSafe for ManageCommentsInput