pub struct ManageDefinedNamesInput {
pub workbook_id: String,
pub action: String,
pub name: Option<String>,
pub formula: Option<String>,
}Fields
workbook_id: Stringaction: String“add” or “list”
name: Option<String>formula: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ManageDefinedNamesInput
impl<'de> Deserialize<'de> for ManageDefinedNamesInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManageDefinedNamesInput
impl JsonSchema for ManageDefinedNamesInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ManageDefinedNamesInput
impl RefUnwindSafe for ManageDefinedNamesInput
impl Send for ManageDefinedNamesInput
impl Sync for ManageDefinedNamesInput
impl Unpin for ManageDefinedNamesInput
impl UnsafeUnpin for ManageDefinedNamesInput
impl UnwindSafe for ManageDefinedNamesInput