pub struct ModifyColumnsInput {
pub workbook_id: String,
pub sheet_name: String,
pub action: String,
pub at_column: String,
pub count: u16,
}Fields
workbook_id: Stringsheet_name: Stringaction: String“insert” or “delete”
at_column: Stringcount: u16Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ModifyColumnsInput
impl<'de> Deserialize<'de> for ModifyColumnsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModifyColumnsInput
impl JsonSchema for ModifyColumnsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModifyColumnsInput
impl RefUnwindSafe for ModifyColumnsInput
impl Send for ModifyColumnsInput
impl Sync for ModifyColumnsInput
impl Unpin for ModifyColumnsInput
impl UnsafeUnpin for ModifyColumnsInput
impl UnwindSafe for ModifyColumnsInput