pub struct ModifyRowsInput {
pub workbook_id: String,
pub sheet_name: String,
pub action: String,
pub at_row: u32,
pub count: u32,
}Fields
workbook_id: Stringsheet_name: Stringaction: String“insert” or “delete”
at_row: u321-based row number
count: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ModifyRowsInput
impl<'de> Deserialize<'de> for ModifyRowsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModifyRowsInput
impl JsonSchema for ModifyRowsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModifyRowsInput
impl RefUnwindSafe for ModifyRowsInput
impl Send for ModifyRowsInput
impl Sync for ModifyRowsInput
impl Unpin for ModifyRowsInput
impl UnsafeUnpin for ModifyRowsInput
impl UnwindSafe for ModifyRowsInput