pub struct PivotChartSourceInput {
pub pivot_table: String,
pub sheet: String,
}Expand description
Pivot chart source
Fields
pivot_table: Stringsheet: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for PivotChartSourceInput
impl<'de> Deserialize<'de> for PivotChartSourceInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PivotChartSourceInput
impl JsonSchema for PivotChartSourceInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PivotChartSourceInput
impl RefUnwindSafe for PivotChartSourceInput
impl Send for PivotChartSourceInput
impl Sync for PivotChartSourceInput
impl Unpin for PivotChartSourceInput
impl UnsafeUnpin for PivotChartSourceInput
impl UnwindSafe for PivotChartSourceInput