pub struct PivotRangeGroupInput {
pub field: String,
pub start: f64,
pub end: f64,
pub interval: f64,
}Fields
field: Stringstart: f64end: f64interval: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PivotRangeGroupInput
impl<'de> Deserialize<'de> for PivotRangeGroupInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PivotRangeGroupInput
impl JsonSchema for PivotRangeGroupInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PivotRangeGroupInput
impl RefUnwindSafe for PivotRangeGroupInput
impl Send for PivotRangeGroupInput
impl Sync for PivotRangeGroupInput
impl Unpin for PivotRangeGroupInput
impl UnsafeUnpin for PivotRangeGroupInput
impl UnwindSafe for PivotRangeGroupInput