pub struct ProtectSheetInput {
pub workbook_id: String,
pub sheet_name: String,
pub password: Option<String>,
}Expand description
Input for protecting a sheet
Fields
workbook_id: Stringsheet_name: Stringpassword: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ProtectSheetInput
impl<'de> Deserialize<'de> for ProtectSheetInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProtectSheetInput
impl JsonSchema for ProtectSheetInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProtectSheetInput
impl RefUnwindSafe for ProtectSheetInput
impl Send for ProtectSheetInput
impl Sync for ProtectSheetInput
impl Unpin for ProtectSheetInput
impl UnsafeUnpin for ProtectSheetInput
impl UnwindSafe for ProtectSheetInput