pub struct SetColumnRangeWidthInput {
pub workbook_id: String,
pub sheet_name: String,
pub first_column: String,
pub last_column: String,
pub width: f64,
}Fields
workbook_id: Stringsheet_name: Stringfirst_column: Stringlast_column: Stringwidth: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetColumnRangeWidthInput
impl<'de> Deserialize<'de> for SetColumnRangeWidthInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetColumnRangeWidthInput
impl JsonSchema for SetColumnRangeWidthInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetColumnRangeWidthInput
impl RefUnwindSafe for SetColumnRangeWidthInput
impl Send for SetColumnRangeWidthInput
impl Sync for SetColumnRangeWidthInput
impl Unpin for SetColumnRangeWidthInput
impl UnsafeUnpin for SetColumnRangeWidthInput
impl UnwindSafe for SetColumnRangeWidthInput