pub struct SetDefaultRowHeightInput {
pub workbook_id: String,
pub sheet_name: String,
pub height: f64,
}Fields
workbook_id: Stringsheet_name: Stringheight: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetDefaultRowHeightInput
impl<'de> Deserialize<'de> for SetDefaultRowHeightInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetDefaultRowHeightInput
impl JsonSchema for SetDefaultRowHeightInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetDefaultRowHeightInput
impl RefUnwindSafe for SetDefaultRowHeightInput
impl Send for SetDefaultRowHeightInput
impl Sync for SetDefaultRowHeightInput
impl Unpin for SetDefaultRowHeightInput
impl UnsafeUnpin for SetDefaultRowHeightInput
impl UnwindSafe for SetDefaultRowHeightInput