pub struct SetDimensionsInput {
pub workbook_id: String,
pub sheet_name: String,
pub target: String,
pub column: Option<String>,
pub first_column: Option<String>,
pub last_column: Option<String>,
pub row: Option<u32>,
pub value: f64,
}Fields
workbook_id: Stringsheet_name: Stringtarget: String“column_width”, “row_height”, “column_range_width”, or “default_row_height”
column: Option<String>first_column: Option<String>last_column: Option<String>row: Option<u32>1-based row number
value: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetDimensionsInput
impl<'de> Deserialize<'de> for SetDimensionsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetDimensionsInput
impl JsonSchema for SetDimensionsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetDimensionsInput
impl RefUnwindSafe for SetDimensionsInput
impl Send for SetDimensionsInput
impl Sync for SetDimensionsInput
impl Unpin for SetDimensionsInput
impl UnsafeUnpin for SetDimensionsInput
impl UnwindSafe for SetDimensionsInput