pub struct SetDocPropertiesInput {
pub workbook_id: String,
pub title: Option<String>,
pub author: Option<String>,
pub subject: Option<String>,
pub description: Option<String>,
pub keywords: Option<String>,
pub category: Option<String>,
pub company: Option<String>,
}Expand description
Input for setting document properties (core + app)
Fields
workbook_id: Stringtitle: Option<String>subject: Option<String>description: Option<String>keywords: Option<String>category: Option<String>company: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetDocPropertiesInput
impl<'de> Deserialize<'de> for SetDocPropertiesInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetDocPropertiesInput
impl JsonSchema for SetDocPropertiesInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetDocPropertiesInput
impl RefUnwindSafe for SetDocPropertiesInput
impl Send for SetDocPropertiesInput
impl Sync for SetDocPropertiesInput
impl Unpin for SetDocPropertiesInput
impl UnsafeUnpin for SetDocPropertiesInput
impl UnwindSafe for SetDocPropertiesInput