pub struct SetPageBreaksInput {
pub workbook_id: String,
pub sheet_name: String,
pub row_breaks: Vec<u32>,
pub col_breaks: Vec<u16>,
}Fields
workbook_id: Stringsheet_name: Stringrow_breaks: Vec<u32>col_breaks: Vec<u16>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetPageBreaksInput
impl<'de> Deserialize<'de> for SetPageBreaksInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetPageBreaksInput
impl JsonSchema for SetPageBreaksInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetPageBreaksInput
impl RefUnwindSafe for SetPageBreaksInput
impl Send for SetPageBreaksInput
impl Sync for SetPageBreaksInput
impl Unpin for SetPageBreaksInput
impl UnsafeUnpin for SetPageBreaksInput
impl UnwindSafe for SetPageBreaksInput