pub struct SetPageSetupInput {Show 14 fields
pub workbook_id: String,
pub sheet_name: String,
pub landscape: Option<bool>,
pub paper_size: Option<u8>,
pub margins: Option<PageMargins>,
pub fit_to_pages: Option<FitToPages>,
pub print_scale: Option<u16>,
pub print_area: Option<String>,
pub repeat_rows: Option<RepeatRows>,
pub header: Option<String>,
pub footer: Option<String>,
pub print_gridlines: Option<bool>,
pub center_horizontally: Option<bool>,
pub center_vertically: Option<bool>,
}Expand description
Input for configuring page setup, headers, footers, print options
Fields
workbook_id: Stringsheet_name: Stringlandscape: Option<bool>paper_size: Option<u8>margins: Option<PageMargins>fit_to_pages: Option<FitToPages>print_scale: Option<u16>print_area: Option<String>Print area in A1:B2 notation
repeat_rows: Option<RepeatRows>header: Option<String>Excel header string (supports &L, &C, &R, &P, &N, &D codes)
Excel footer string
print_gridlines: Option<bool>center_horizontally: Option<bool>center_vertically: Option<bool>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetPageSetupInput
impl<'de> Deserialize<'de> for SetPageSetupInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetPageSetupInput
impl JsonSchema for SetPageSetupInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetPageSetupInput
impl RefUnwindSafe for SetPageSetupInput
impl Send for SetPageSetupInput
impl Sync for SetPageSetupInput
impl Unpin for SetPageSetupInput
impl UnsafeUnpin for SetPageSetupInput
impl UnwindSafe for SetPageSetupInput