pub struct SetRowHiddenInput {
pub workbook_id: String,
pub sheet_name: String,
pub row: u32,
pub hidden: bool,
}Fields
workbook_id: Stringsheet_name: Stringrow: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetRowHiddenInput
impl<'de> Deserialize<'de> for SetRowHiddenInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetRowHiddenInput
impl JsonSchema for SetRowHiddenInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetRowHiddenInput
impl RefUnwindSafe for SetRowHiddenInput
impl Send for SetRowHiddenInput
impl Sync for SetRowHiddenInput
impl Unpin for SetRowHiddenInput
impl UnsafeUnpin for SetRowHiddenInput
impl UnwindSafe for SetRowHiddenInput