pub struct SetSheetSettingsInput {
pub workbook_id: String,
pub sheet_name: String,
pub hidden: Option<bool>,
pub very_hidden: Option<bool>,
pub zoom: Option<u16>,
pub hide_gridlines: Option<bool>,
pub hide_headings: Option<bool>,
pub tab_color: Option<String>,
pub right_to_left: Option<bool>,
}Expand description
Input for sheet display settings
Fields
workbook_id: Stringsheet_name: Stringzoom: Option<u16>hide_gridlines: Option<bool>hide_headings: Option<bool>tab_color: Option<String>right_to_left: Option<bool>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SetSheetSettingsInput
impl<'de> Deserialize<'de> for SetSheetSettingsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetSheetSettingsInput
impl JsonSchema for SetSheetSettingsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetSheetSettingsInput
impl RefUnwindSafe for SetSheetSettingsInput
impl Send for SetSheetSettingsInput
impl Sync for SetSheetSettingsInput
impl Unpin for SetSheetSettingsInput
impl UnsafeUnpin for SetSheetSettingsInput
impl UnwindSafe for SetSheetSettingsInput