pub struct SheetProtectionOptionsInput {Show 13 fields
pub password: Option<String>,
pub insert_rows: Option<bool>,
pub delete_rows: Option<bool>,
pub insert_columns: Option<bool>,
pub delete_columns: Option<bool>,
pub format_cells: Option<bool>,
pub format_columns: Option<bool>,
pub format_rows: Option<bool>,
pub sort: Option<bool>,
pub insert_hyperlinks: Option<bool>,
pub select_locked_cells: Option<bool>,
pub select_unlocked_cells: Option<bool>,
pub pivot_tables: Option<bool>,
}Expand description
Sheet protection with granular options
Fields
password: Option<String>insert_rows: Option<bool>delete_rows: Option<bool>insert_columns: Option<bool>delete_columns: Option<bool>format_cells: Option<bool>format_columns: Option<bool>format_rows: Option<bool>sort: Option<bool>insert_hyperlinks: Option<bool>select_locked_cells: Option<bool>select_unlocked_cells: Option<bool>pivot_tables: Option<bool>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SheetProtectionOptionsInput
impl<'de> Deserialize<'de> for SheetProtectionOptionsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SheetProtectionOptionsInput
impl JsonSchema for SheetProtectionOptionsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SheetProtectionOptionsInput
impl RefUnwindSafe for SheetProtectionOptionsInput
impl Send for SheetProtectionOptionsInput
impl Sync for SheetProtectionOptionsInput
impl Unpin for SheetProtectionOptionsInput
impl UnsafeUnpin for SheetProtectionOptionsInput
impl UnwindSafe for SheetProtectionOptionsInput