pub struct ThreadedReplyInput {
pub author: String,
pub text: String,
pub timestamp: Option<String>,
}Fields
text: Stringtimestamp: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ThreadedReplyInput
impl<'de> Deserialize<'de> for ThreadedReplyInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ThreadedReplyInput
impl JsonSchema for ThreadedReplyInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadedReplyInput
impl RefUnwindSafe for ThreadedReplyInput
impl Send for ThreadedReplyInput
impl Sync for ThreadedReplyInput
impl Unpin for ThreadedReplyInput
impl UnsafeUnpin for ThreadedReplyInput
impl UnwindSafe for ThreadedReplyInput