pub struct View3DInput {
pub rot_x: Option<i16>,
pub rot_y: Option<i16>,
pub perspective: Option<u8>,
}Fields
rot_x: Option<i16>rot_y: Option<i16>perspective: Option<u8>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for View3DInput
impl<'de> Deserialize<'de> for View3DInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for View3DInput
impl JsonSchema for View3DInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for View3DInput
impl RefUnwindSafe for View3DInput
impl Send for View3DInput
impl Sync for View3DInput
impl Unpin for View3DInput
impl UnsafeUnpin for View3DInput
impl UnwindSafe for View3DInput