pub struct WriteBlankInput {
pub workbook_id: String,
pub sheet_name: String,
pub cell: String,
pub bold: Option<bool>,
pub background_color: Option<String>,
pub number_format: Option<String>,
}Fields
workbook_id: Stringsheet_name: Stringcell: Stringbold: Option<bool>background_color: Option<String>number_format: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for WriteBlankInput
impl<'de> Deserialize<'de> for WriteBlankInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WriteBlankInput
impl JsonSchema for WriteBlankInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WriteBlankInput
impl RefUnwindSafe for WriteBlankInput
impl Send for WriteBlankInput
impl Sync for WriteBlankInput
impl Unpin for WriteBlankInput
impl UnsafeUnpin for WriteBlankInput
impl UnwindSafe for WriteBlankInput