pub struct WriteInternalLinkInput {
pub workbook_id: String,
pub sheet_name: String,
pub cell: String,
pub location: String,
pub display_text: String,
}Fields
workbook_id: Stringsheet_name: Stringcell: Stringlocation: StringInternal location (e.g. “Sheet2!A1”)
display_text: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for WriteInternalLinkInput
impl<'de> Deserialize<'de> for WriteInternalLinkInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WriteInternalLinkInput
impl JsonSchema for WriteInternalLinkInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WriteInternalLinkInput
impl RefUnwindSafe for WriteInternalLinkInput
impl Send for WriteInternalLinkInput
impl Sync for WriteInternalLinkInput
impl Unpin for WriteInternalLinkInput
impl UnsafeUnpin for WriteInternalLinkInput
impl UnwindSafe for WriteInternalLinkInput