pub struct WriteRichTextInput {
pub workbook_id: String,
pub sheet_name: String,
pub cell: String,
pub runs: Vec<RichTextRunInput>,
}Expand description
Input for writing rich text to a cell
Fields
workbook_id: Stringsheet_name: Stringcell: Stringruns: Vec<RichTextRunInput>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for WriteRichTextInput
impl<'de> Deserialize<'de> for WriteRichTextInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WriteRichTextInput
impl JsonSchema for WriteRichTextInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WriteRichTextInput
impl RefUnwindSafe for WriteRichTextInput
impl Send for WriteRichTextInput
impl Sync for WriteRichTextInput
impl Unpin for WriteRichTextInput
impl UnsafeUnpin for WriteRichTextInput
impl UnwindSafe for WriteRichTextInput